@@ -21,13 +21,8 @@
 #include <solid/config-solid.h>
 #include <stdlib.h>
 
-#if HAVE_SYS_MNTTAB_H
-#include <sys/mnttab.h>
-#endif
 #if HAVE_MNTENT_H
 #include <mntent.h>
-#elif defined(HAVE_SYS_MNTENT_H)
-#include <sys/mntent.h>
 #endif
 
 // This is the *BSD branch
@@ -41,55 +36,11 @@
 #include <sys/mount.h>
 #endif
 
-#ifdef Q_OS_SOLARIS
-#define FSTAB "/etc/vfstab"
-#else
 #define FSTAB "/etc/fstab"
-#endif
 
-#if !HAVE_GETMNTINFO
-#ifdef _PATH_MOUNTED
-// On some Linux, MNTTAB points to /etc/fstab !
-#undef MNTTAB
-#define MNTTAB _PATH_MOUNTED
-#else
-#ifndef MNTTAB
-#ifdef MTAB_FILE
-#define MNTTAB MTAB_FILE
-#else
-#define MNTTAB "/etc/mnttab"
-#endif
-#endif
-#endif
-#endif
-
-// There are (at least) four kind of APIs:
+// There are currently two APIs implemented:
 // setmntent + getmntent + struct mntent (linux...)
-//             getmntent + struct mnttab
 // getmntinfo + struct statfs&flags (BSD 4.4 and friends)
-// getfsent + char* (BSD 4.3 and friends)
-
-#if HAVE_SETMNTENT
-#define SETMNTENT setmntent
-#define ENDMNTENT endmntent
-#define STRUCT_MNTENT struct mntent *
-#define STRUCT_SETMNTENT FILE *
-#define GETMNTENT(file, var) ((var = getmntent(file)) != nullptr)
-#define MOUNTPOINT(var) var->mnt_dir
-#define MOUNTTYPE(var) var->mnt_type
-#define MOUNTOPTIONS(var) var->mnt_opts
-#define FSNAME(var) var->mnt_fsname
-#else
-#define SETMNTENT fopen
-#define ENDMNTENT fclose
-#define STRUCT_MNTENT struct mnttab
-#define STRUCT_SETMNTENT FILE *
-#define GETMNTENT(file, var) (getmntent(file, &var) == nullptr)
-#define MOUNTPOINT(var) var.mnt_mountp
-#define MOUNTTYPE(var) var.mnt_fstype
-#define MOUNTOPTIONS(var) var.mnt_mntopts
-#define FSNAME(var) var.mnt_special
-#endif
 
 Q_GLOBAL_STATIC(QThreadStorage<Solid::Backends::Fstab::FstabHandling>, globalFstabCache)
 
@@ -101,12 +52,12 @@ Solid::Backends::Fstab::FstabHandling::FstabHandling()
 
 bool _k_isFstabNetworkFileSystem(const QString &fstype, const QString &devName)
 {
-    if (fstype == "nfs" //
-        || fstype == "nfs4" //
-        || fstype == "smbfs" //
-        || fstype == "cifs" //
-        || fstype == "smb3" //
-        || fstype == "fuse.sshfs" //
+    if (fstype == QLatin1String("nfs") //
+        || fstype == QLatin1String("nfs4") //
+        || fstype == QLatin1String("smbfs") //
+        || fstype == QLatin1String("cifs") //
+        || fstype == QLatin1String("smb3") //
+        || fstype == QLatin1String("fuse.sshfs") //
         || devName.startsWith(QLatin1String("//"))) {
         return true;
     }
@@ -115,10 +66,10 @@ bool _k_isFstabNetworkFileSystem(const QString &fstype, const QString &devName)
 
 bool _k_isFstabSupportedLocalFileSystem(const QString &fstype)
 {
-    if (fstype == "fuse.encfs" //
-        || fstype == "fuse.cryfs" //
-        || fstype == "fuse.gocryptfs" //
-        || fstype == "overlay") {
+    if (fstype == QLatin1String("fuse.encfs") //
+        || fstype == QLatin1String("fuse.cryfs") //
+        || fstype == QLatin1String("fuse.gocryptfs") //
+        || fstype == QLatin1String("overlay")) {
         return true;
     }
     return false;
@@ -126,7 +77,7 @@ bool _k_isFstabSupportedLocalFileSystem(const QString &fstype)
 
 QString _k_deviceNameForMountpoint(const QString &source, const QString &fstype, const QString &mountpoint)
 {
-    if (fstype.startsWith("fuse.") || fstype == QLatin1String("overlay")) {
+    if (fstype.startsWith(QLatin1String("fuse.")) || fstype == QLatin1String("overlay")) {
         return fstype + mountpoint;
     }
     // A source may be mounted several times, e.g. with different
@@ -135,7 +86,7 @@ QString _k_deviceNameForMountpoint(const QString &source, const QString &fstype,
     // mountpoint (which is unique).
 
     auto _mountpoint = mountpoint;
-    if (fstype == "nfs" || fstype == "nfs4") {
+    if (fstype == QLatin1String("nfs") || fstype == QLatin1String("nfs4")) {
         if (!mountpoint.startsWith(QLatin1Char('/'))) {
             // making sure mount point starts with /
             _mountpoint.prepend(QLatin1Char('/'));
@@ -181,7 +132,7 @@ void Solid::Backends::Fstab::FstabHandling::_k_updateFstabMountPointsCache()
 
 #else
 
-    QFile fstab(FSTAB);
+    QFile fstab(QStringLiteral(FSTAB));
     if (!fstab.open(QIODevice::ReadOnly)) {
         return;
     }
@@ -191,29 +142,23 @@ void Solid::Backends::Fstab::FstabHandling::_k_updateFstabMountPointsCache()
 
     while (!stream.atEnd()) {
         line = stream.readLine().simplified();
-        if (line.isEmpty() || line.startsWith('#')) {
+        if (line.isEmpty() || line.startsWith(QLatin1Char('#'))) {
             continue;
         }
 
         // not empty or commented out by '#'
-        const QStringList items = line.split(' ');
-
-#ifdef Q_OS_SOLARIS
-        if (items.count() < 5) {
-            continue;
-        }
-#else
+        const QStringList items = line.split(QLatin1Char(' '));
         if (items.count() < 4) {
             continue;
         }
-#endif
+
         // prevent accessing a blocking directory
         if (_k_isFstabNetworkFileSystem(items.at(2), items.at(0)) || _k_isFstabSupportedLocalFileSystem(items.at(2))) {
             const QString device = items.at(0);
             const QString fsType = items.at(2);
             QString mountpoint = items.at(1);
 
-            if (fsType == "nfs" || fsType == "nfs4") {
+            if (fsType == QLatin1String("nfs") || fsType == QLatin1String("nfs4")) {
                 if (!mountpoint.startsWith(QLatin1Char('/'))) {
                     // making sure mount point starts with /
                     mountpoint.prepend(QLatin1Char('/'));
@@ -295,7 +240,7 @@ bool Solid::Backends::Fstab::FstabHandling::callSystemCommand(const QString &com
     static const QString joinedPaths = searchPaths.join(QLatin1Char(':'));
     const QString exec = QStandardPaths::findExecutable(commandName, searchPaths);
     if (exec.isEmpty()) {
-        qCWarning(FSTAB_LOG) << "Couldn't find executable " + commandName + " in " + joinedPaths;
+        qCWarning(FSTAB_LOG) << "Couldn't find executable" << commandName << "in" << joinedPaths;
         return false;
     }
 
@@ -355,23 +300,23 @@ void Solid::Backends::Fstab::FstabHandling::_k_updateMtabMountPointsCache()
     }
 
 #else
-    STRUCT_SETMNTENT mnttab;
-    if ((mnttab = SETMNTENT(MNTTAB, "r")) == nullptr) {
+    FILE *mnttab;
+    if ((mnttab = setmntent("/etc/mtab", "r")) == nullptr) {
         return;
     }
 
-    STRUCT_MNTENT fe;
-    while (GETMNTENT(mnttab, fe)) {
-        QString type = QFile::decodeName(MOUNTTYPE(fe));
+    struct mntent *fe;
+    while ((fe = getmntent(mnttab)) != nullptr) {
+        const QString type = QFile::decodeName(fe->mnt_type);
         if (_k_isFstabNetworkFileSystem(type, QString()) || _k_isFstabSupportedLocalFileSystem(type)) {
-            const QString fsname = QFile::decodeName(FSNAME(fe));
-            const QString mountpoint = QFile::decodeName(MOUNTPOINT(fe));
+            const QString fsname = QFile::decodeName(fe->mnt_fsname);
+            const QString mountpoint = QFile::decodeName(fe->mnt_dir);
             const QString device = _k_deviceNameForMountpoint(fsname, type, mountpoint);
             globalFstabCache->localData().m_mtabCache.insert(device, mountpoint);
             globalFstabCache->localData().m_fstabFstypeCache.insert(device, type);
         }
     }
-    ENDMNTENT(mnttab);
+    endmntent(mnttab);
 #endif
 
     globalFstabCache->localData().m_mtabCacheValid = true;
